Struct log_writer::LogWriterConfig
source · [−]pub struct LogWriterConfig {
pub target_dir: PathBuf,
pub prefix: String,
pub suffix: String,
pub max_use_of_total: Option<f64>,
pub max_use_bytes: Option<u64>,
pub min_avail_of_total: Option<f64>,
pub warn_if_avail_reached: bool,
pub min_avail_bytes: Option<usize>,
pub max_file_size: usize,
pub max_file_age: Option<u64>,
pub reserved: Option<usize>,
}Fields
target_dir: PathBufprefix: Stringsuffix: Stringmax_use_of_total: Option<f64>The maximum amount of space that is allowed to be used, relative to the total space (0.01 = 1%)
max_use_bytes: Option<u64>The maximum amount of space that is allowed to be used, in bytes
min_avail_of_total: Option<f64>The minimum amount of space that should be kept available at all times, relative to the total space (0.01 = 1%)
warn_if_avail_reached: boolmin_avail_bytes: Option<usize>The minimum amount of space that should be kept available at all times, in bytes
max_file_size: usizemax_file_age: Option<u64>Rotated after X seconds, regardless of size
reserved: Option<usize>Disk space subtracted when checking if max_use_of_total is reached. Set this to the absolute amount of space you expect other services to take up on the partition. in bytes