Struct log_writer::LogWriterConfig [−][src]
pub struct LogWriterConfig {
pub target_dir: PathBuf,
pub prefix: String,
pub suffix: String,
pub max_use_of_total: Option<f64>,
pub min_avail_of_total: Option<f64>,
pub warn_if_avail_reached: bool,
pub min_avail_bytes: Option<usize>,
pub max_file_size: usize,
}Fields
target_dir: PathBufprefix: Stringsuffix: Stringmax_use_of_total: Option<f64>The maximum amount of space that is allowed to be used, relative to the total space (0.01 = 1%)
min_avail_of_total: Option<f64>The minimum amount of space that should be kept available at all times, relative to the total space (0.01 = 1%)
warn_if_avail_reached: boolmin_avail_bytes: Option<usize>The minimum amount of space that should be kept available at all times, in bytes
max_file_size: usizeTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.